@@ -26,11 +26,16 @@
 .onAttach <- function( ... )
 {
   rgenoudLib <- dirname(system.file(package = "rgenoud"))
-  version <- packageDescription("rgenoud", lib = rgenoudLib)$Version
-  BuildDate <- packageDescription("rgenoud", lib = rgenoudLib)$Date
-  
-  cat(paste("##  rgenoud (Version ", version, ", Build Date: ", BuildDate, ")\n", sep = ""))
-  cat("##  See http://sekhon.berkeley.edu/rgenoud for additional documentation.\n")
+  version <- packageDescription("rgenoud", lib.loc = rgenoudLib)$Version
+  BuildDate <- packageDescription("rgenoud", lib.loc = rgenoudLib)$Date
+
+  foo <- paste("##  rgenoud (Version ", version, ", Build Date: ", BuildDate, ")\n",
+               "##  See http://sekhon.berkeley.edu/rgenoud for additional documentation.\n",
+               "##  Please cite software as:\n",
+               "##   Walter Mebane, Jr. and Jasjeet S. Sekhon. 2011.\n",
+               "##   ``Genetic Optimization Using Derivatives: The rgenoud package for R.''\n",
+               "##   Journal of Statistical Software, 42(11): 1-26. \n##\n",               
+               sep = "")
+
+  packageStartupMessage(foo)
 }
-
-
